summaryrefslogtreecommitdiffstats
path: root/tdeui/klineedit.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:22 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:22 -0600
commit28edc0aa2ab09297288186f5bc15765eb7be58c0 (patch)
tree7b7a01768b3781763186c825af21bb14717d2c32 /tdeui/klineedit.h
parent07c48c43ff72c237e4028154f4594102b798073f (diff)
downloadtdelibs-28edc0aa2ab09297288186f5bc15765eb7be58c0.tar.gz
tdelibs-28edc0aa2ab09297288186f5bc15765eb7be58c0.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'tdeui/klineedit.h')
-rw-r--r--tdeui/klineedit.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/tdeui/klineedit.h b/tdeui/klineedit.h
index fc1f4ba4a..84e554316 100644
--- a/tdeui/klineedit.h
+++ b/tdeui/klineedit.h
@@ -80,7 +80,7 @@ class KURL;
* second argument.
*
* If @p EchoMode for this widget is set to something other than @p TQLineEdit::Normal,
* the completion mode will always be defaulted to KGlobalSettings::CompletionNone.
* This is done purposefully to guard against protected entries such as passwords being
* cached in KCompletion's list. Hence, if the @p EchoMode is not TQLineEdit::Normal, the
* completion mode is automatically disabled.
@@ -204,7 +204,7 @@ public:
*
* See KCompletionBase::setCompletionMode
*/
- virtual void setCompletionMode( KGlobalSettings::Completion mode );
+ virtual void setCompletionMode( TDEGlobalSettings::Completion mode );
/**
* Enables/disables the popup (context) menu.
@@ -269,7 +269,7 @@ public:
/**
* @returns the completion-box, that is used in completion mode
- * KGlobalSettings::CompletionPopup.
+ * TDEGlobalSettings::CompletionPopup.
* This method will create a completion-box if none is there, yet.
*
* @param create Set this to false if you don't want the box to be created
@@ -320,7 +320,7 @@ public:
/**
* Set the completion-box to be used in completion mode
- * KGlobalSettings::CompletionPopup.
+ * TDEGlobalSettings::CompletionPopup.
* This will do nothing if a completion-box already exists.
*
* @param box The KCompletionBox to set
@@ -382,7 +382,7 @@ signals:
* @p setKeyBinding for details.
*
* Note that this signal is @em not emitted if the completion
* mode is set to @p KGlobalSettings::CompletionNone or
* @p echoMode() is @em not normal.
*/
void textRotation( KCompletionBase::KeyBindingType );
@@ -391,7 +391,7 @@ signals:
* Emitted when the user changed the completion mode by using the
* popupmenu.
*/
- void completionModeChanged( KGlobalSettings::Completion );
+ void completionModeChanged( TDEGlobalSettings::Completion );
/**
* Emitted before the context menu is displayed.
@@ -80,7 +80,7 @@ class KURL;
*
* If @p EchoMode for this widget is set to something other than @p TQLineEdit::Normal,
- * the completion mode will always be defaulted to KGlobalSettings::CompletionNone.
+ * the completion mode will always be defaulted to TDEGlobalSettings::CompletionNone.
* This is done purposefully to guard against protected entries such as passwords being
* cached in KCompletion's list. Hence, if the @p EchoMode is not TQLineEdit::Normal, the
@@ -382,7 +382,7 @@ signals:
*
* Note that this signal is @em not emitted if the completion
- * mode is set to @p KGlobalSettings::CompletionNone or
+ * mode is set to @p TDEGlobalSettings::CompletionNone or
* @p echoMode() is @em not normal.
*/